@@ -1,7 +1,7 @@
 use fuel_asm::Opcode;
 use fuel_core::service::{Config, FuelService};
 use fuel_gql_client::client::FuelClient;
-use fuel_tx::{Receipt, Salt, Transaction};
+use fuel_tx::{Receipt, Salt, Transaction, UtxoId};
 use fuel_types::{Bytes32, ContractId};
 use fuel_vm::consts::REG_ZERO;
 use fuels_rs::contract::{CompiledContract, Contract};
@@ -80,7 +80,7 @@ async fn contract_call() {
     let balance_root: [u8; 32] = rng.gen();
     let state_root: [u8; 32] = rng.gen();
 
-    let utxo_id = Bytes32::from(utxo_id);
+    let utxo_id = UtxoId::new(Bytes32::from(utxo_id), 0);
     let balance_root = Bytes32::from(balance_root);
     let state_root = Bytes32::from(state_root);
     let gas_price = 0;
